@@ -1,9 +1,14 @@
 import chromadb.config
 import logging
+from chromadb.telemetry.events import ClientStartEvent
+from chromadb.telemetry.posthog import Posthog
 
+logger = logging.getLogger(__name__)
 
 __settings = chromadb.config.Settings()
 
+__version__ = "0.3.13"
+
 
 def configure(**kwargs):
     """Override Chroma's default settings, environment variables or .env files"""
@@ -26,7 +31,7 @@ def get_db(settings=__settings):
         require("clickhouse_host")
         require("clickhouse_port")
         require("persist_directory")
-        print("Using Clickhouse for database")
+        logger.info("Using Clickhouse for database")
         import chromadb.db.clickhouse
 
         return chromadb.db.clickhouse.Clickhouse(settings)
@@ -37,12 +42,14 @@ def get_db(settings=__settings):
         return chromadb.db.duckdb.PersistentDuckDB(settings)
     elif setting == "duckdb":
         require("persist_directory")
-        print("Using DuckDB in-memory for database. Data will be transient.")
+        logger.info("Using DuckDB in-memory for database. Data will be transient.")
         import chromadb.db.duckdb
 
         return chromadb.db.duckdb.DuckDB(settings)
     else:
-        raise ValueError(f"Expected chroma_db_impl to be one of clickhouse, duckdb, duckdb+parquet, got {setting}")
+        raise ValueError(
+            f"Expected chroma_db_impl to be one of clickhouse, duckdb, duckdb+parquet, got {setting}"
+        )
 
 
 def Client(settings=__settings):
@@ -50,6 +57,10 @@ def Client(settings=__settings):
     settings, optionally overriding the DB instance."""
 
     setting = settings.chroma_api_impl.lower()
+    telemetry_client = Posthog(settings)
+
+    # Submit event for client start
+    telemetry_client.capture(ClientStartEvent())
 
     def require(key):
         assert settings[key], f"Setting '{key}' is required when chroma_api_impl={setting}"
@@ -57,14 +68,14 @@ def Client(settings=__settings):
     if setting == "rest":
         require("chroma_server_host")
         require("chroma_server_http_port")
-        print("Running Chroma in client mode using REST to connect to remote server")
+        logger.info("Running Chroma in client mode using REST to connect to remote server")
         import chromadb.api.fastapi
 
-        return chromadb.api.fastapi.FastAPI(settings)
+        return chromadb.api.fastapi.FastAPI(settings, telemetry_client)
     elif setting == "local":
-        print("Running Chroma using direct local API.")
+        logger.info("Running Chroma using direct local API.")
         import chromadb.api.local
 
-        return chromadb.api.local.LocalAPI(settings, get_db(settings))
+        return chromadb.api.local.LocalAPI(settings, get_db(settings), telemetry_client)
     else:
         raise ValueError(f"Expected chroma_api_impl to be one of rest, local, got {setting}")
