@@ -17,10 +17,12 @@ from chromadb.api.types import (
 )
 import json
 
+from chromadb.telemetry import Telemetry
+
 
 class API(ABC):
     @abstractmethod
-    def __init__(self):
+    def __init__(self, telemetry_client: Telemetry):
         pass
 
     @abstractmethod
