@@ -4,12 +4,13 @@ import time
 from typing import Optional
 import uuid
 from chromadb.api.types import IndexMetadata
-
 import hnswlib
 import numpy as np
 from chromadb.db.index import Index
-from chromadb.logger import logger
 from chromadb.errors import NoIndexException, InvalidDimensionException
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 class Hnswlib(Index):
