@@ -28,6 +28,10 @@ from chromadb.server.fastapi.types import (
 )
 from starlette.requests import Request
 from starlette.responses import Response
+import logging
+from chromadb.telemetry import ServerContext, Telemetry
+
+logger = logging.getLogger(__name__)
 
 
 def use_route_names_as_operation_ids(app: FastAPI) -> None:
@@ -45,13 +49,14 @@ async def catch_exceptions_middleware(request: Request, call_next):
     try:
         return await call_next(request)
     except Exception as e:
-        print("ERROR: ", e)
+        logger.exception(e)
         return JSONResponse(content={"error": repr(e)}, status_code=500)
 
 
 class FastAPI(chromadb.server.Server):
     def __init__(self, settings):
         super().__init__(settings)
+        Telemetry.SERVER_CONTEXT = ServerContext.FASTAPI
         self._app = fastapi.FastAPI(debug=True)
         self._api = chromadb.Client(settings)
 
